@@ -12,7 +12,7 @@ BEGIN { use base 'Exporter';
 
 =head1 NAME 
 
-Module::Loaded -- mark modules as loaded or unloaded
+Module::Loaded - mark modules as loaded or unloaded
 
 =head1 SYNOPSIS
 
@@ -117,20 +117,18 @@ sub _pm_to_file {
     return $file;
 }    
 
+=head1 BUG REPORTS
+
+Please report bugs or other issues to E<lt>bug-module-loaded@rt.cpan.org<gt>.
+
 =head1 AUTHOR
 
-This module by
-Jos Boumans E<lt>kane@cpan.orgE<gt>.
+This module by Jos Boumans E<lt>kane@cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-This module is
-copyright (c) 2004-2005 Jos Boumans E<lt>kane@cpan.orgE<gt>.
-All rights reserved.
-
-This library is free software;
-you may redistribute and/or modify it under the same
-terms as Perl itself.
+This library is free software; you may redistribute and/or modify it 
+under the same terms as Perl itself.
 
 =cut
 
