@@ -217,7 +217,7 @@ sub _query_report {
 
 =pod
 
-=head2 $bool = $cb->_send_report( module => $modobj, buffer => $make_output, failed => BOOL, [save => BOOL, address => $email_to, dontcc => BOOL, verbose => BOOL, force => BOOL]);
+=head2 $bool = $cb->_send_report( module => $modobj, buffer => $make_output, failed => BOOL, [save => BOOL, address => $email_to, verbose => BOOL, force => BOOL]);
 
 This function sends a testers report to C<cpan-testers@perl.org> for a
 particular distribution.
@@ -254,16 +254,6 @@ override this, but it might be useful for debugging purposes.
 
 Defaults to C<cpan-testers@perl.org>.
 
-=item dontcc
-
-Boolean indicating whether or not we should Cc: the author. If false,
-previous error reports are inspected and checked if the author should
-be mailed. If set to true, these tests are skipped and the author is
-definitely not Cc:'d.
-You should probably not change this setting.
-
-Defaults to false.
-
 =item verbose
 
 Boolean indicating on whether or not to be verbose.
@@ -296,7 +286,7 @@ sub _send_report {
     }
 
     ### check arguments ###
-    my ($buffer, $failed, $mod, $verbose, $force, $address, $save, $dontcc,
+    my ($buffer, $failed, $mod, $verbose, $force, $address, $save, 
         $tests_skipped );
     my $tmpl = {
             module  => { required => 1, store => \$mod, allow => IS_MODOBJ },
@@ -304,7 +294,6 @@ sub _send_report {
             failed  => { required => 1, store => \$failed },
             address => { default  => CPAN_TESTERS_EMAIL, store => \$address },
             save    => { default  => 0, store => \$save },
-            dontcc  => { default  => 0, store => \$dontcc },
             verbose => { default  => $conf->get_conf('verbose'),
                             store => \$verbose },
             force   => { default  => $conf->get_conf('force'),
@@ -325,6 +314,9 @@ sub _send_report {
     my $cb      = $mod->parent;
 
 
+    ### will be 'fetch', 'make', 'test', 'install', etc ###
+    my $stage   = TEST_FAIL_STAGE->($buffer);
+
     ### determine the grade now ###
 
     my $grade;
@@ -405,6 +397,10 @@ sub _send_report {
         ### see if the thing even had tests ###
         } elsif ( NO_TESTS_DEFINED->( $buffer ) ) {
             $grade = GRADE_UNKNOWN;
+        ### failures in PL or make/build stage are now considered UNKNOWN
+        } elsif ( $stage !~ /\btest\b/ ) {
+
+            $grade = GRADE_UNKNOWN
 
         } else {
             
@@ -418,7 +414,10 @@ sub _send_report {
     } }
 
     ### so an error occurred, let's see what stage it went wrong in ###
-    my $message;
+
+    ### the header -- always include so the CPANPLUS version is apparent
+    my $message =  REPORT_MESSAGE_HEADER->( $int_ver, $author );
+
     if( $grade eq GRADE_FAIL or $grade eq GRADE_UNKNOWN) {
 
         ### return if one or more missing external libraries
@@ -428,16 +427,10 @@ sub _send_report {
             return 1;
         }
 
-        ### will be 'fetch', 'make', 'test', 'install', etc ###
-        my $stage   = TEST_FAIL_STAGE->($buffer);
-
         ### return if we're only supposed to report make_test failures ###
         return 1 if $cp_conf =~  /\bmaketest_only\b/i
                     and ($stage !~ /\btest\b/);
 
-        ### the header
-        $message =  REPORT_MESSAGE_HEADER->( $int_ver, $author );
-
         ### the bit where we inform what went wrong
         $message .= REPORT_MESSAGE_FAIL_HEADER->( $stage, $buffer );
 
@@ -469,52 +462,38 @@ sub _send_report {
     ### that tests got skipped, since the buffer is not added in
     } elsif ( $tests_skipped ) {
         $message .= REPORT_TESTS_SKIPPED->();
-    }        
-
-    ### if it failed, and that already got reported, we're not cc'ing the
-    ### author. Also, 'dont_cc' might be in the config, so check this;
-    my $dont_cc_author = $dontcc;
-
-    unless( $dont_cc_author ) {
-        if( $cp_conf =~ /\bdont_cc\b/i ) {
-            $dont_cc_author++;
-
-        } elsif ( $grade eq GRADE_PASS ) {
-            $dont_cc_author++
-
-        } elsif( $grade eq GRADE_FAIL ) {
-            my @already_sent =
-                $self->_query_report( module => $mod, verbose => $verbose );
-
-            ### if we can't fetch it, we'll just assume no one
-            ### mailed him yet
-            my $count = 0;
-            if( @already_sent ) {
-                for my $href (@already_sent) {
-                    $count++ if uc $href->{'grade'} eq uc GRADE_FAIL;
-                }
-            }
-
-            if( $count > MAX_REPORT_SEND and !$force) {
-                msg(loc("'%1' already reported for '%2', ".
-                        "not cc-ing the author",
-                        GRADE_FAIL, $dist ), $verbose );
-                $dont_cc_author++;
-            }
-        }
-    }
+    } elsif( $grade eq GRADE_NA) {
     
+        ### the bit where we inform what went wrong
+        $message .= REPORT_MESSAGE_FAIL_HEADER->( $stage, $buffer );
+
+        ### the footer
+        $message .= REPORT_MESSAGE_FOOTER->();
+
+    }
+
     msg( loc("Sending test report for '%1'", $dist), $verbose);
 
     ### reporter object ###
-    my $reporter = Test::Reporter->new(
-                        grade           => $grade,
-                        distribution    => $dist,
-                        via             => "CPANPLUS $int_ver",
-                        timeout         => $conf->get_conf('timeout') || 60,
-                        debug           => $conf->get_conf('debug'),
-                    );
-                    
+    my $reporter = do {
+        my $args = $conf->get_conf('cpantest_reporter_args') || {};
+        
+        unless( UNIVERSAL::isa( $args, 'HASH' ) ) {
+            error(loc("'%1' must be a hashref, ignoring...",
+                      'cpantest_reporter_args'));
+            $args = {};
+        }
+        
+        Test::Reporter->new(
+            grade           => $grade,
+            distribution    => $dist,
+            via             => "CPANPLUS $int_ver",
+            timeout         => $conf->get_conf('timeout') || 60,
+            debug           => $conf->get_conf('debug'),
+            %$args,
+        );
+    };
+    
     ### set a custom mx, if requested
     $reporter->mx( [ $conf->get_conf('cpantest_mx') ] ) 
         if $conf->get_conf('cpantest_mx');
@@ -546,10 +525,6 @@ sub _send_report {
         $reporter->edit_comments;
     }
 
-    ### people to mail ###
-    my @inform;
-    #push @inform, $email unless $dont_cc_author;
-
     ### allow to be overridden, but default to the normal address ###
     $reporter->address( $address );
 
@@ -565,9 +540,8 @@ sub _send_report {
             return;
         }
 
-    ### should we send it to a bunch of people? ###
     ### XXX should we do an 'already sent' check? ###
-    } elsif( $reporter->send( @inform ) ) {
+    } elsif( $reporter->send( ) ) {
         msg(loc("Successfully sent '%1' report for '%2'", $grade, $dist),
             $verbose);
         return 1;
